clear all;

initial = [pi/2; pi/2];     % initial joint configuration
distance = pi/4;            % target distance in radians
directions = 8;             % number of directions
dt = 0.01;                  % time step
n = 50;                     % number of time steps

% form initial state and control
x0 = [initial; zeros(2,1)];
u0 = [0; 0];

figure(1);
clf;

% loop over directions
for d = 1:directions
    alpha = 2*pi*d/directions;
    target = initial + distance*[cos(alpha); sin(alpha)];
    fnCost = @(x_,u_,t_) arm_cost(x_,u_,t_,target);
    
    % solve optimization problem
    x = ilqg_det(@arm_dyn, fnCost, dt, n, x0, u0);
    
    % plot path in joint space
    plot(x(1,:),x(2,:),'k');
    hold on;
    plot(target(1),target(2),'o');
end
axis image;
xlabel('shoulder (rad)');
ylabel('elbow (rad)');
